# streamlit-autogui

Vibe code inside a streamlit application and prompt for technical implementations coupled with GUI components on the fly. Give tweaks on top of the generated code if needed.

## Installation instructions

```sh
pip install streamlit-autogui
```

## Usage instructions

```python
import streamlit as st

from autogui import autogui

# Add some example here
value = None

st.write(value)
```
